use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( lib bin script ) );
__DATA__
Assert
Bessarabov
Env
Functions
Ivan
Koivunalho
Mikko
Ron
Savage
bin
dotenv
env
envassert
envdot
gregoa
gregor
herrmann
ivan
lib
mikkoi
ron
